aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/utility.hxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2019-08-21 12:11:48 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2019-08-21 12:11:48 +0200
commitd64ae97f6865bc25d496485622530e2a090c2eb4 (patch)
treeeef35c80417a9a08c7713368261aa6d1e8632b5d /libbuild2/utility.hxx
parentd7b5f03a761714f6ea6c4b1891e8a1f3824d4979 (diff)
Implement dynamic loading of build system modules
Diffstat (limited to 'libbuild2/utility.hxx')
-rw-r--r--libbuild2/utility.hxx6
1 files changed, 5 insertions, 1 deletions
diff --git a/libbuild2/utility.hxx b/libbuild2/utility.hxx
index c251b64..ed94a08 100644
--- a/libbuild2/utility.hxx
+++ b/libbuild2/utility.hxx
@@ -71,10 +71,13 @@ namespace build2
using butl::trim;
using butl::next_word;
+ using butl::sanitize_identifier;
using butl::make_guard;
using butl::make_exception_guard;
+ using butl::function_cast;
+
using butl::getenv;
using butl::setenv;
using butl::unsetenv;
@@ -136,9 +139,10 @@ namespace build2
//
LIBBUILD2_SYMEXPORT extern process_path argv0;
// Build system driver version and check.
//
LIBBUILD2_SYMEXPORT extern const standard_version build_version;
+ LIBBUILD2_SYMEXPORT extern const string build_version_interface;
LIBBUILD2_SYMEXPORT extern bool dry_run_option; // --dry-run
@@ -136,9 +139,10 @@ namespace build2
//
LIBBUILD2_SYMEXPORT extern process_path argv0;
- // Build system driver version and check.
+ // Build system core version and interface version.
//
LIBBUILD2_SYMEXPORT extern const standard_version build_version;